#include "SerialDriverNames.h"

#include <Errors.h>
#include <Memory.h>
#include <CommResources.h>
#include <CRMSerialDevices.h>


static TSerialDriverName *fDriverNames = nil;
static short fNumDriverNames = 0;

static OSErr GetName(short index, Str255 name, short type);


OSErr NewNameTable(void)
{
	OSErr err;
	CRMRec c;
	CRMRecPtr cPtr = &c;
	CRMSerialPtr serialPtr;

	err = noErr;
	DisposeNameTable();
	fDriverNames = (TSerialDriverName *) NewPtr(0);
	
	InitCRM();
	
	c.crmDeviceType = crmSerialDevice;
	c.crmDeviceID   = 0;
	while (cPtr != nil) {
		cPtr = (CRMRecPtr)CRMSearch((CRMRecPtr)cPtr);
		if (cPtr) {
			serialPtr = (CRMSerialPtr)cPtr->crmAttributes;

			SetPtrSize((Ptr)fDriverNames, (fNumDriverNames+1)*sizeof(TSerialDriverName));
			err = MemError();
			if (err != noErr) break;
			BlockMove((void *) *(serialPtr->name),
			          (void *) &fDriverNames[fNumDriverNames].driver,
			          (*(serialPtr->name))[0]+1);
			BlockMove((void *) *(serialPtr->inputDriverName),
			          (void *) &fDriverNames[fNumDriverNames].inputDriver,
			          (*(serialPtr->inputDriverName))[0]+1);
			BlockMove((void *) *(serialPtr->outputDriverName),
			          (void *) &fDriverNames[fNumDriverNames].outputDriver,
			          (*(serialPtr->outputDriverName))[0]+1);
			fNumDriverNames++;

			c.crmDeviceID = cPtr->crmDeviceID;
		}
	}
	return err;
}

void DisposeNameTable(void)
{
	if (fDriverNames != nil) {
		DisposePtr((Ptr)fDriverNames);
		fDriverNames = nil;
		fNumDriverNames = 0;
	}
}

OSErr GetNumDriverNames(short *numDriverNames)
{
	OSErr err;
	
	*numDriverNames = 0;
	err = noErr;
	if (fDriverNames == nil) {
		err = NewNameTable();
	}
	if (err == noErr) {
		*numDriverNames = fNumDriverNames;
	}
	
	return err;
}


OSErr GetName(short index, Str255 name, short type)
{
	OSErr err;

	err = noErr;
	if (fDriverNames == nil) {
		err = NewNameTable();
	}
	if ((err == noErr)  && ((index < 0) || (index >= fNumDriverNames))) {
		err = paramErr;
	}
	if (err == noErr) {
		switch (type) {
			case 0:
				BlockMove(fDriverNames[index].driver,
				          name,
				          fDriverNames[index].driver[0]+1);
				break;
			case 1:
				BlockMove(fDriverNames[index].inputDriver,
				          name,
				          fDriverNames[index].inputDriver[0]+1);
				break;
			case 2:
				BlockMove(fDriverNames[index].outputDriver,
				          name,
				          fDriverNames[index].outputDriver[0]+1);
				break;
		}
		err = MemError();
	}
	
	return err;
}

OSErr GetDriverName(short index, Str255 name)
{
	return GetName(index, name, 0);
}
OSErr GetInputDriverName(short index, Str255 name)
{
	return GetName(index, name, 1);
}
OSErr GetOutputDriverName(short index, Str255 name)
{
	return GetName(index, name, 2);
}