/******************************************************************************
 **																			 **
 ** 	Module:		DriverBird.h											 **
 ** 																		 **
 ** 																		 **
 ** 	Purpose: 	Public routines defined by the Ascension Flock Of Birds	 **
 ** 	         	driver.													 **
 ** 																		 **
 ** 																		 **
 ** 	(C) 1997 Maarten Gribnau, m.w.gribnau@io.tudelft.nl					 **
 ** 																		 **
 ** 																		 **
 *****************************************************************************/
#pragma once

#ifndef DriverBird_h
#define DriverBird_h

#include <Types.h>

// Controls whether choice for poll/stream operation mode is supported
#define OPERATION_MODE 0


typedef enum {
	sync_None = 0x00,   /* Internal sync */
	sync_CRT1 = 0x01,	/* Vertical retrace rates >72 Hz, <144 Hz */
	sync_CRT2 = 0x02,	/* Vertical retrace rates <72Hz */
	sync_Host = 0x08	/* Host sync mode */
} TBirdSync;

#if OPERATION_MODE
typedef enum {
	mode_Poll = 0,
	mode_Stream
} TBirdOperation;
#endif

typedef enum {
	mode_Relative = 0,
	mode_Absolute
} TBirdMode;

typedef enum {
	range_36 = 0,
	range_72 = 1
} TBirdRange;

typedef struct {
	Boolean		standAlone;
	short		numBirdsFound;
	short		numBirdsOperating;
	Byte		softwareRevInt;
	Byte		softwareRevFrac;
	Byte		crystalSpeed;
} TBirdInformation;

typedef struct {
	Boolean			ACNarrowOn;
	Boolean			ACWideOn;
	Boolean			DCOn;
	UInt16			measurementRate;
	Boolean			suddenOutputElimination;
	TBirdSync		sync;
	TBirdRange		range;
//	Boolean			xyzReferenceFrame;
//	Boolean			groupMode;
} TBirdConfiguration;


/******************************************************************************
 **																			 **
 **									 Routines								 **
 **																			 **
 *****************************************************************************/
 
OSErr BirdInit(
	short portID,
	short speed,
	TBirdConfiguration *config,
#if OPERATION_MODE
	TBirdOperation operationMode,
#endif
	TBirdMode mode,
	float inch2qd3dX,
	float inch2qd3dY,
	float inch2qd3dZ,
	Boolean controlCursor);
OSErr BirdTerm(
	void);

OSErr BirdSetPort(
	short portID,
	short speed);
short BirdGetPort(
	void);
short BirdGetPortSpeed(
	void);

OSErr BirdGetInformation(
	TBirdInformation *info);
OSErr BirdGetConfiguration(
	TBirdConfiguration *config);
OSErr BirdSetConfiguration(
	TBirdConfiguration *config);

OSErr BirdGetSyncData(
	float *outVoltage,
	float *outScanRate);

#if OPERATION_MODE
TBirdOperation BirdGetOperation(
	void);
OSErr BirdSetOperation(
	TBirdOperation operation);
#endif
	
TBirdMode BirdGetMode(
	void);
void BirdSetMode(
	TBirdMode mode);

Boolean BirdGetIsRunning(
	void);
OSErr BirdStopRunning(
	void);
OSErr BirdStartRunning(
	void);

#if OPERATION_MODE
OSErr BirdPoll(
	void);
#endif

void BirdGetInch2QD3D(
	float *x,
	float *y,
	float *z);
void BirdSetInch2QD3D(
	float x,
	float y,
	float z);
	
void BirdSetControlCursor(
	Boolean controlCursor);
Boolean BirdGetControlCursor(
	void);

#endif  /*  DriverBird_h  */