/******************************************************************************
 **                                                                         **
 ** 	Module:		PrefFile.c                                              **
 **                                                                         **
 **                                                                         **
 **   Purpose:  Routines to handle preference files.                        **
 **                                                                         **
 **                                                                         **
 **   Maarten Gribnau.                                                      **
 **   m.w.gribnau@io.tudelft.nl                                             **
 **                                                                         **
 **                                                                         **
 *****************************************************************************/

#include "PrefFile.h"

#include <Folders.h>
#include <Errors.h>

void
GetPreferencesFile(
	OSType creator,
	ConstStr255Param name,
	FSSpec* spec)
{
	OSErr	fsErr;
	
	fsErr = FindFolder(kOnSystemDisk,
	                   'pref',
	                   kCreateFolder,
	                   &(spec->vRefNum),
	                   &(spec->parID));
	fsErr = FSMakeFSSpec(spec->vRefNum,
	                     spec->parID,
	                     name,
	                     spec);
	
	if (fsErr == fnfErr) { 
		NewPreferencesFile(creator, spec);
	}
}


OSErr
NewPreferencesFile(
	OSType creator,
	FSSpec *spec)
{
	return FSpCreate(spec, creator, 'pref', -1);
}


void
LoadPreferences(
	FSSpec *spec,
	TPreferences *prefs)
{
	short refNum = -1;
	OSErr	err;
	long	fileLength;
	Str15 port = "\pNone";
	
	err = FSpOpenDF(spec, fsCurPerm, &refNum);
	if (err) goto bail;
	err = GetEOF(refNum, &fileLength);
	if (err) goto bail;
	if (fileLength != sizeof(TPreferences)) goto bail;
	err = SetFPos(refNum, fsFromStart, 0);
	if (err) goto bail;
	err = FSRead(refNum, &fileLength, prefs);
	if (err) goto bail;
	FSClose(refNum);
	return;
		
bail:
	if (refNum != -1) {
		FSClose(refNum);
	}
	GetDefaultPreferences(prefs);
}


void
GetDefaultPreferences(
	TPreferences *prefs)
{
	/* Set default preferences */
	prefs->port = -1;
	prefs->speed = baud9600;
	prefs->configuration.ACNarrowOn = false;
	prefs->configuration.ACWideOn = true;
	prefs->configuration.DCOn = true;
	prefs->configuration.measurementRate = 103*256;
	prefs->configuration.suddenOutputElimination = false;
	prefs->configuration.sync = sync_None;
	prefs->configuration.range = range_36;
	prefs->mode = mode_Relative,
	prefs->inch2qd3dX = 1.;
	prefs->inch2qd3dY = 1.;
	prefs->inch2qd3dZ = 1.;
	prefs->controlCursor = false;
}


void
SavePreferences(
	FSSpec *spec,
	TPreferences *prefs)

{
	short refNum = -1;
	OSErr	err;
	long byteCount = sizeof (TPreferences);
	long bytesWritten = byteCount;

	err = FSpOpenDF(spec, fsCurPerm, &refNum);
	if (err) goto bail;
	err = SetFPos(refNum, fsFromStart, 0);
	if (err) goto bail;
	err = FSWrite(refNum, &bytesWritten, prefs);
	if (err) goto bail;
	err = SetEOF(refNum, bytesWritten);
	err = FSClose(refNum);
	return;
	
bail:
	if (refNum != -1) {
		FSClose(refNum);
	}
}