/******************************************************************************
 **																			 **
 ** 	Module:		DriverDynasight.h										 **
 ** 																		 **
 ** 																		 **
 ** 	Purpose: 	Public routines defined by the Dynasight driver.		 **
 ** 																		 **
 ** 																		 **
 ** 	(C) 1997 Maarten Gribnau m.w.gribnau@io.tudelft.nl					 **
 ** 																		 **
 ** 																		 **
 *****************************************************************************/
#pragma once

#ifndef DriverDynasight_h
#define DriverDynasight_h

#include <Types.h>

typedef enum {
	err_NotResponding = 50,
	err_Controller,
	err_QD3DInitialise
} TDynaError;

typedef enum {
	oper_Poll = 0,
	oper_Stream = 1
} TDynaOperationMode;

typedef struct {
	short				serialPort;
	TDynaOperationMode	operationMode;
	float				offsetX;		// In inches
	float				offsetY;		// In inches
	float				offsetZ;		// In inches
	float				scaleX;			// In QD3D units per inch
	float				scaleY;			// In QD3D units per inch
	float				scaleZ;			// In QD3D units per inch
	Boolean				controlCursor;
} TDynaConfiguration;

/******************************************************************************
 **																			 **
 **									 Routines								 **
 **																			 **
 *****************************************************************************/
 
OSErr DynaInit(
	TDynaConfiguration *config);

#if POLL_MODE
OSErr DynaPoll(
	void);
#endif

OSErr DynaTerm(
	void);
	
Boolean DynaGetIsRunning(
	void);
OSErr DynaStartRunning(
	void);
OSErr DynaStopRunning(
	void);

OSErr DynaSetConfiguration(
	TDynaConfiguration *config);
void DynaGetConfiguration(
	TDynaConfiguration *config);

#endif  /*  DriverOwl_h  */
